@@ -8,6 +8,7 @@ from __future__ import print_function
 import os
 import re
 import json
+import errno
 
 from io import open
 from time import time
@@ -19,7 +20,7 @@ from .util import Print, Preproc as Pp
 from functools import reduce
 from six.moves import xrange
 
-__version__ = "0.3.7"
+__version__ = "0.3.9.1"
 
 ENCODING = "utf-8"
 
@@ -32,6 +33,9 @@ STR_UNKNOWN_CATEGORY = "[UNKNOWN]"
 STR_VANILLA, STR_XAI = "vanilla", "xai"
 STR_GV, STR_NORM_GV, STR_NORM_GV_XAI = "gv", "norm_gv", "norm_gv_xai"
 
+STR_MODEL_FOLDER = "ss3_models"
+STR_MODEL_EXT = "ss3m"
+
 NAME = 0
 VOCAB = 1
 
@@ -79,8 +83,7 @@ class SS3:
     """
 
     __name__ = "model"
-    __models_folder__ = "ss3_models"
-    __models_ext__ = "ss3m"
+    __models_folder__ = STR_MODEL_FOLDER
 
     __s__ = .45
     __l__ = .5
@@ -717,23 +720,22 @@ class SS3:
 
         By default it returns the addition of all confidence
         vectors. However, in case you want to use a custom
-        wants to use a custom summary operator, this function
-        must be replaced as shown in the following example:
+        summary operator, this function must be replaced
+        as shown in the following example:
 
-            >>> def dummy_summary_op(cvs):
+            >>> def my_summary_op(cvs):
             >>>     return cvs[0]
             >>> ...
             >>> clf = SS3()
             >>> ...
-            >>> clf.summary_op_ngrams = dummy_summary_op
+            >>> clf.summary_op_ngrams = my_summary_op
 
-        Note that any function receiving a list of (confidence)
-        vectors and returning a single (confidence) vector
-        could be used. In the example above the summary operator
-        is replaced by the user-defined ``dummy_summary_op`` which
-        ignores all confidence vectors returning only the confidence
-        vector of the first n-gram (which besides being an
-        illustrative example, makes no real sense).
+        Note that any function receiving a list of vectors and
+        returning a single vector could be used. In the above example
+        the summary operator is replaced by the user-defined
+        ``my_summary_op`` which ignores all confidence vectors
+        returning only the confidence vector of the first n-gram
+        (which besides being an illustrative example, makes no real sense).
 
         :param cvs: a list n-grams confidence vectors
         :type cvs: list (of list of float)
@@ -748,8 +750,8 @@ class SS3:
 
         By default it returns the addition of all confidence
         vectors. However, in case you want to use a custom
-        wants to use a custom summary operator, this function
-        must be replaced as shown in the following example:
+        summary operator, this function must be replaced
+        as shown in the following example:
 
             >>> def dummy_summary_op(cvs):
             >>>     return cvs[0]
@@ -758,13 +760,12 @@ class SS3:
             >>> ...
             >>> clf.summary_op_sentences = dummy_summary_op
 
-        Note that any function receiving a list of (confidence)
-        vectors and returning a single (confidence) vector
-        could be used. In the example above the summary operator
-        is replaced by the user-defined ``dummy_summary_op`` which
-        ignores all confidence vectors returning only the confidence
-        vector of the first sentence (which besides being an
-        illustrative example, makes no real sense).
+        Note that any function receiving a list of vectors and
+        returning a single vector could be used. In the above example
+        the summary operator is replaced by the user-defined
+        ``dummy_summary_op`` which ignores all confidence vectors
+        returning only the confidence vector of the first sentence
+        (which besides being an illustrative example, makes no real sense).
 
         :param cvs: a list sentence confidence vectors
         :type cvs: list (of list of float)
@@ -779,8 +780,8 @@ class SS3:
 
         By default it returns the addition of all confidence
         vectors. However, in case you want to use a custom
-        wants to use a custom summary operator, this function
-        must be replaced as shown in the following example:
+        summary operator, this function must be replaced
+        as shown in the following example:
 
             >>> def dummy_summary_op(cvs):
             >>>     return cvs[0]
@@ -789,13 +790,12 @@ class SS3:
             >>> ...
             >>> clf.summary_op_paragraphs = dummy_summary_op
 
-        Note that any function receiving a list of (confidence)
-        vectors and returning a single (confidence) vector
-        could be used. In the example above the summary operator
-        is replaced by the user-defined ``dummy_summary_op`` which
-        ignores all confidence vectors returning only the confidence
-        vector of the first paragraph (which besides being an
-        illustrative example, makes no real sense).
+        Note that any function receiving a list of vectors and
+        returning a single vector could be used. In the above example
+        the summary operator is replaced by the user-defined
+        ``dummy_summary_op`` which ignores all confidence vectors
+        returning only the confidence vector of the first paragraph
+        (which besides being an illustrative example, makes no real sense).
 
         :param cvs: a list paragraph confidence vectors
         :type cvs: list (of list of float)
@@ -846,6 +846,21 @@ class SS3:
         """
         return self.__s__, self.__l__, self.__p__, self.__a__
 
+    def set_model_path(self, path):
+        """
+        Set the path from which our model will be loaded (or saved to).
+
+        Note: be aware that the PySS3 Command Line tool looks for
+        a local folder called "ss3_models" to load models from.
+        Therefore, the "ss3_models" folder will be always automatically
+        append to given ``path`` (e.g. if ``path`` = "my/path/", it will
+        be converted into "my/path/ss3_models").
+
+        :param path: a path
+        :type path: str
+        """
+        self.__models_folder__ = os.path.join(path, STR_MODEL_FOLDER)
+
     def set_s(self, value):
         """
         Set the "smoothness" (sigma) hyperparameter value.
@@ -1078,7 +1093,7 @@ class SS3:
         Print.info(
             "saving model (%s/%s.%s)..."
             %
-            (self.__models_folder__, self.__name__, self.__models_ext__),
+            (self.__models_folder__, self.__name__, STR_MODEL_EXT),
             False
         )
         json_file_format = {
@@ -1097,16 +1112,21 @@ class SS3:
         }
 
         try:
-            os.mkdir(self.__models_folder__)
-        except OSError:
-            pass
+            os.makedirs(self.__models_folder__)
+        except OSError as ose:
+            if ose.errno == errno.EEXIST and os.path.isdir(self.__models_folder__):
+                pass
+            else:
+                raise
+
         json_file = open(
             "%s/%s.%s" % (
                 self.__models_folder__,
                 self.__name__,
-                self.__models_ext__
+                STR_MODEL_EXT
             ), "w", encoding=ENCODING
         )
+
         try:  # python 3
             json_file.write(json.dumps(json_file_format))
         except TypeError:  # python 2
@@ -1128,7 +1148,7 @@ class SS3:
             "%s/%s.%s" % (
                 self.__models_folder__,
                 self.__name__,
-                self.__models_ext__
+                STR_MODEL_EXT
             ), "r", encoding=ENCODING
         )
         json_file_format = json.loads(json_file.read(), object_hook=key_as_int)
