@@ -127,7 +127,10 @@ class Server:
         if not data:
             return
 
-        data = data.decode()
+        try:
+            data = data.decode()
+        except UnicodeDecodeError:
+            Print.error("UnicodeDecodeError: __handle_request__")
 
         rsc_path = get_http_path(data)
 
@@ -146,6 +149,9 @@ class Server:
                 Server.__do_get_info__(sock)
             elif method == "get_doc":
                 Server.__do_get_doc__(sock, body)
+            else:
+                sock.send(HTTP_404)
+                Print.info("404 Not Found")
 
         else:  # if GET
             Print.show("\tGET %s " % rsc_path, False)
@@ -224,6 +230,8 @@ class Server:
     def __clear_testset__():
         """Clear server's test documents."""
         Server.__docs__ = RecursiveDefaultDict()
+        Server.__test_path__ = None
+        Server.__folder_label__ = None
         Server.__x_test__ = None
 
     @staticmethod
@@ -452,7 +460,6 @@ class Server:
 
         server_socket = Server.__server_socket__
         clients = [server_socket]
-        sock_to_addr = {}
 
         if browser:
             webbrowser.open("http://localhost:%d" % Server.__port__)
@@ -465,23 +472,24 @@ class Server:
 
         try:
             while True:
-                read_socks, write_socks, error_socks = select(clients, [], [])
+                try:
+                    read_socks, write_socks, error_socks = select(clients, [], [])
 
-                for sock in read_socks:
+                    for sock in read_socks:
+                        if sock is server_socket:
+                            sockfd, addr = server_socket.accept()
+                            clients.append(sockfd)
+                            Print.show(
+                                Print.style.green("[ %s : %s ]")
+                                % (addr[0], datetime.now())
+                            )
+                        else:
+                            Server.__handle_request__(sock)
+                            clients.remove(sock)
+                            sock.close()
 
-                    if sock is server_socket:
-                        sockfd, addr = server_socket.accept()
-                        clients.append(sockfd)
-                        sock_to_addr[sockfd.fileno()] = addr[0]
-                        Print.show(
-                            Print.style.green("[ %s : %s ]")
-                            % (addr[0], datetime.now())
-                        )
-                    else:
-                        Server.__handle_request__(sock)
-                        clients.remove(sock)
-                        del sock_to_addr[sock.fileno()]
-                        sock.close()
+                except Exception as e:
+                    Print.error("Exception: " + str(e))
         except KeyboardInterrupt:
             Print.info("closing server...")
             server_socket.close()
@@ -529,6 +537,6 @@ if __name__ == "__main__":
         Server.set_testset_from_files(args.path, args.label == 'folder')
 
     try:
-        Server.serve(port=args.port, browser=False)
+        Server.serve(port=args.port, browser=False, quiet=args.quiet)
     except IOError:
         Print.error("Error: port number already in use")
